pub struct Events {
pub items: Option<Vec<Event>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list events (response)
Fields
items: Option<Vec<Event>>The event list.
kind: Option<String>The kind for a page of events.
next_page_token: Option<String>The ‘pageToken’ to pass to the next request to get the next page, if there are more to retrieve.