pub struct LinkMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on link resources.
It is not used directly, but through the Gan hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_gan1_beta1 as gan1_beta1;
use gan1_beta1::{Gan, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Gan::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `get(...)`, `insert(...)` and `list(...)`
// to build up your call.
let rb = hub.links();Implementations
Sourceimpl<'a, C> LinkMethods<'a, C>
impl<'a, C> LinkMethods<'a, C>
Sourcepub fn get(&self, role: &str, role_id: &str, link_id: i64) -> LinkGetCall<'a, C>
pub fn get(&self, role: &str, role_id: &str, link_id: i64) -> LinkGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves data about a single link if the requesting advertiser/publisher has access to it. Advertisers can look up their own links. Publishers can look up visible links or links belonging to advertisers they are in a relationship with.
Arguments
role- The role of the requester. Valid values: ‘advertisers’ or ‘publishers’.roleId- The ID of the requesting advertiser or publisher.linkId- The ID of the link to look up.
Sourcepub fn insert(
&self,
request: Link,
role: &str,
role_id: &str,
) -> LinkInsertCall<'a, C>
pub fn insert( &self, request: Link, role: &str, role_id: &str, ) -> LinkInsertCall<'a, C>
Create a builder to help you perform the following task:
Inserts a new link.
Arguments
request- No description provided.role- The role of the requester. Valid values: ‘advertisers’ or ‘publishers’.roleId- The ID of the requesting advertiser or publisher.
Sourcepub fn list(&self, role: &str, role_id: &str) -> LinkListCall<'a, C>
pub fn list(&self, role: &str, role_id: &str) -> LinkListCall<'a, C>
Create a builder to help you perform the following task:
Retrieves all links that match the query parameters.
Arguments
role- The role of the requester. Valid values: ‘advertisers’ or ‘publishers’.roleId- The ID of the requesting advertiser or publisher.