pub struct ReportMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on report resources.
It is not used directly, but through the Gan hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_gan1_beta1 as gan1_beta1;
use gan1_beta1::{Gan, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Gan::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `get(...)`
// to build up your call.
let rb = hub.reports();Implementations
Sourceimpl<'a, C> ReportMethods<'a, C>
impl<'a, C> ReportMethods<'a, C>
Sourcepub fn get(
&self,
role: &str,
role_id: &str,
report_type: &str,
) -> ReportGetCall<'a, C>
pub fn get( &self, role: &str, role_id: &str, report_type: &str, ) -> ReportGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a report of the specified type.
Arguments
role- The role of the requester. Valid values: ‘advertisers’ or ‘publishers’.roleId- The ID of the requesting advertiser or publisher.reportType- The type of report being requested. Valid values: ‘order_delta’. Required.