pub struct CcOfferRewards {
pub additional_details: Option<String>,
pub amount: Option<f64>,
pub category: Option<String>,
pub expiration_months: Option<f64>,
pub max_reward_tier: Option<f64>,
pub min_reward_tier: Option<f64>,
}Expand description
For cards with rewards programs, detailed rules about how the program works.
This type is not used in any activity, and only used as part of another schema.
Fields
additional_details: Option<String>Other limits, for example, if this rule only applies during an introductory period.
amount: Option<f64>The number of units rewarded per purchase dollar.
category: Option<String>The kind of purchases covered by this rule.
expiration_months: Option<f64>How long rewards granted by this rule last.
max_reward_tier: Option<f64>The maximum purchase amount in the given category for this rule to apply.
min_reward_tier: Option<f64>The minimum purchase amount in the given category before this rule applies.